@@ -1,8 +1,5 @@
 package CatalystX::Resource::TraitFor::Controller::Resource::Sortable;
-{
-  $CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.007_003';
-}
-
+$CatalystX::Resource::TraitFor::Controller::Resource::Sortable::VERSION = '0.009_001';
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
@@ -56,20 +53,21 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 CatalystX::Resource::TraitFor::Controller::Resource::Sortable - makes your resource sortable
 
 =head1 VERSION
 
-version 0.007_003
+version 0.009_001
 
 =head1 SYNOPSIS
 
     # TestApp.pm
     'Controller::Resource::Artist' => {
-        resultset_key => 'artists_rs',
-        resources_key => 'artists',
+        resultset_key => 'artists',
         resource_key => 'artist',
         form_class => 'TestApp::Form::Resource::Artist',
         model => 'DB::Resource::Artist',
